@@ -7,17 +7,17 @@ def run(path_to_config: str):
 
 
 def train_lgbm():
-    path_to_config = "configs/lgbm_config.pb"
+    path_to_config = "configs/lgbm_config.yaml"
     run(path_to_config)
 
 
 def train_xgboost():
-    path_to_config = "configs/xgboost_config.pb"
+    path_to_config = "configs/xgboost_config.yaml"
     run(path_to_config)
 
 
 def train_catboost():
-    path_to_config = "configs/catboost_config.pb"
+    path_to_config = "configs/catboost_config.yaml"
     run(path_to_config)
 
 
