@@ -2,9 +2,9 @@
 
 from typing import Any, Dict, List, Union
 
+from tabml.config_helpers import parse_pipeline_config
 from tabml.experiment_manager import ExperimentManger
 from tabml.utils import factory
-from tabml.utils.pb_helpers import parse_pipeline_config_pb
 
 
 class ModelInference:
@@ -15,13 +15,16 @@ class ModelInference:
         model_path: str,
         pipeline_config_path: Union[str, None] = None,
         custom_model_wrapper=None,
+        transformer_path=None,
     ):
-        self.fm = feature_manager_cls(feature_config_path)
+        self.fm = feature_manager_cls(
+            feature_config_path, transformer_path=transformer_path
+        )
         if pipeline_config_path is None:
             pipeline_config_path = ExperimentManger.get_config_path_from_model_path(
                 model_path
             )
-        self.config = parse_pipeline_config_pb(pipeline_config_path)
+        self.config = parse_pipeline_config(pipeline_config_path)
         if custom_model_wrapper:
             self.model_wrapper = custom_model_wrapper(self.config)
         else:
