@@ -1,13 +1,15 @@
 from abc import ABC, abstractmethod
-from typing import Any, Dict, Iterable, Union
+from typing import Any, Dict, Iterable, Tuple, Union
 
 import mlflow
 from catboost import CatBoostClassifier, CatBoostRegressor
 from lightgbm import LGBMClassifier, LGBMRegressor
 from xgboost import XGBClassifier, XGBRegressor
 
+from tabml.data_loaders import BaseDataLoader
 from tabml.utils import utils
-from tabml.utils.pb_helpers import pb_to_dict
+from tabml.utils.logger import boosting_logger_eval
+from tabml.utils.utils import save_as_pickle
 
 MLFLOW_AUTOLOG = {
     "lightgbm": mlflow.lightgbm.autolog(),
@@ -25,6 +27,9 @@ class BaseModelWrapper(ABC):
         self.feature_names = list(self.config.data_loader.features_to_model)
         self.params: Union[Dict[str, Any], None] = None
 
+    def fit(self, data_loader: BaseDataLoader, model_dir: str):
+        pass
+
     @abstractmethod
     def predict(self, data) -> Iterable:
         """Predicts data inputs."""
@@ -43,12 +48,39 @@ class BaseModelWrapper(ABC):
         raise NotImplementedError
 
 
-class BaseLgbmModelWrapper(BaseModelWrapper):
+class BaseBoostingModelWrapper(BaseModelWrapper):
+    """A common model wrapper for boosting models.
+
+    Boosting models: LightGBM, XGBoost, CatBoost."""
+
+    def __init__(self, config):
+        super().__init__(config)
+        self.save_model_name = "model_0"
+
+    @abstractmethod
+    def _get_fit_params(self, train_data: Tuple, val_data: Tuple) -> Dict:
+        raise NotImplementedError
+
+    def fit(self, data_loader: BaseDataLoader, model_dir: str):
+        assert (
+            data_loader.label_col is not None
+        ), "data_loader.label_col must be declared in BaseDataLoader subclasses."
+        train_feature, train_label = data_loader.get_train_data_and_label()
+        val_data = data_loader.get_val_data_and_label()
+
+        fit_params = self._get_fit_params((train_feature, train_label), val_data)
+
+        # breakpoint()
+        self.model.fit(X=train_feature, y=train_label, **fit_params)
+        save_as_pickle(self.model, model_dir, self.save_model_name)
+
+
+class BaseLgbmModelWrapper(BaseBoostingModelWrapper):
     mlflow_model_type = "lightgbm"
 
     def __init__(self, config):
         super().__init__(config)
-        self.params = pb_to_dict(self.config.model_wrapper.lgbm_params)
+        self.params = self.config.model_wrapper.model_params
         self.model = self.build_model()
 
     @abstractmethod
@@ -61,6 +93,15 @@ class BaseLgbmModelWrapper(BaseModelWrapper):
     def load_model(self, model_path: str):
         self.model = utils.load_pickle(model_path)
 
+    def _get_fit_params(self, train_data: Tuple, val_data: Tuple) -> Dict:
+        fit_params = {
+            "eval_set": [train_data, val_data],
+            "eval_names": ["train", "val"],
+            "callbacks": [boosting_logger_eval(model="lgbm")],
+            **self.config.model_wrapper.fit_params,
+        }
+        return fit_params
+
 
 class LgbmClassifierModelWrapper(BaseLgbmModelWrapper):
     def build_model(self):
@@ -75,12 +116,12 @@ class LgbmRegressorModelWrapper(BaseLgbmModelWrapper):
         return LGBMRegressor(**self.params)
 
 
-class BaseXGBoostModelWrapper(BaseModelWrapper):
+class BaseXGBoostModelWrapper(BaseBoostingModelWrapper):
     mlflow_model_type = "xgboost"
 
     def __init__(self, config):
         super(BaseXGBoostModelWrapper, self).__init__(config)
-        self.params = pb_to_dict(self.config.model_wrapper.xgboost_params)
+        self.params = self.config.model_wrapper.model_params
         self.tree_method = "gpu_hist" if utils.is_gpu_available() else "auto"
         self.model = self.build_model()
 
@@ -94,6 +135,14 @@ class BaseXGBoostModelWrapper(BaseModelWrapper):
     def load_model(self, model_path: str):
         self.model = utils.load_pickle(model_path)
 
+    def _get_fit_params(self, train_data, val_data):
+        fit_params = {
+            "eval_set": [train_data, val_data],
+            "callbacks": [boosting_logger_eval(model="xgboost")],
+            **self.config.model_wrapper.fit_params,
+        }
+        return fit_params
+
 
 class XGBoostRegressorModelWrapper(BaseXGBoostModelWrapper):
     def build_model(self):
@@ -108,12 +157,12 @@ class XGBoostClassifierModelWrapper(BaseXGBoostModelWrapper):
         return self.model.predict_proba(data)[:, 1]
 
 
-class BaseCatBoostModelWrapper(BaseModelWrapper):
+class BaseCatBoostModelWrapper(BaseBoostingModelWrapper):
     mlflow_model_type = "catboost"
 
     def __init__(self, config):
         super(BaseCatBoostModelWrapper, self).__init__(config)
-        self.params = pb_to_dict(self.config.model_wrapper.catboost_params)
+        self.params = self.config.model_wrapper.model_params
         self.task_type = "GPU" if utils.is_gpu_available() else "CPU"
         self.model = self.build_model()
 
@@ -127,6 +176,11 @@ class BaseCatBoostModelWrapper(BaseModelWrapper):
     def load_model(self, model_path: str):
         self.model = utils.load_pickle(model_path)
 
+    def _get_fit_params(self, train_data, val_data):
+        fit_params = {"eval_set": [val_data]}
+
+        return fit_params
+
 
 class CatBoostClassifierModelWrapper(BaseCatBoostModelWrapper):
     def build_model(self):
