@@ -3,12 +3,11 @@ from abc import ABC
 import mlflow
 
 from tabml import experiment_manager, model_wrappers
+from tabml.config_helpers import parse_pipeline_config
 from tabml.data_loaders import BaseDataLoader
 from tabml.model_analysis import ModelAnalysis
-from tabml.trainers import BaseTrainer
 from tabml.utils import factory
 from tabml.utils.logger import logger
-from tabml.utils.pb_helpers import parse_pipeline_config_pb
 
 
 class BasePipeline(ABC):
@@ -20,8 +19,6 @@ class BasePipeline(ABC):
             (passed via path_to_config when initialized)
         data_loader:
             a data loader object, a subclass of base.data_loaders.BaseDataLoader.
-        trainer:
-            a trainer object, a subclass of base.trainers.BaseTrainer.
         exp_manager:
             a base.experiment_manager.ExperimentManager object.
         custom_model_wrapper:
@@ -37,11 +34,10 @@ class BasePipeline(ABC):
         self.exp_manager = experiment_manager.ExperimentManger(
             path_to_config, custom_run_dir=custom_run_dir
         )
-        self.config = parse_pipeline_config_pb(path_to_config)
+        self.config = parse_pipeline_config(path_to_config)
         self.data_loader = self._get_data_loader()
         assert self.data_loader.label_col is not None, "label_col must be specified"
         self._get_model_wrapper(custom_model_wrapper)
-        self.trainer = self._get_trainer()
 
         logger.add(self.exp_manager.get_log_path())
 
@@ -59,7 +55,7 @@ class BasePipeline(ABC):
     def train(self):
         model_dir = self.exp_manager.run_dir
         logger.info("Start training the model.")
-        self.trainer.train(model_dir)
+        self.model_wrapper.fit(self.data_loader, model_dir)
 
     def _get_data_loader(self) -> BaseDataLoader:
         return factory.create(self.config.data_loader.cls_name)(self.config)
@@ -72,11 +68,6 @@ class BasePipeline(ABC):
                 self.config
             )
 
-    def _get_trainer(self) -> BaseTrainer:
-        return factory.create(self.config.trainer.cls_name)(
-            self.model_wrapper, self.data_loader, self.config
-        )
-
     def analyze_model(self) -> None:
         """Analyze the model on the validation dataset.
 
@@ -93,11 +84,6 @@ class BasePipeline(ABC):
             "Add the by_features in model_analysis in the pipeline config"
         )
 
-        # In protocol buffer, default value for int32 is 0.
-        if self.config.model_analysis.training_size == 0:
-            training_size = None
-        else:
-            training_size = self.config.model_analysis.training_size
         ModelAnalysis(
             data_loader=self.data_loader,
             model_wrapper=self.model_wrapper,
@@ -105,5 +91,5 @@ class BasePipeline(ABC):
             label_to_analyze=self.config.model_analysis.by_label,
             metric_names=self.config.model_analysis.metrics,
             output_dir=self.exp_manager.get_model_analysis_dir(),
-            training_size=training_size,
+            training_size=self.config.model_analysis.training_size,
         ).analyze()
